@@ -1,9 +1,12 @@
+# coding: utf-8
+
 import os
 import subprocess
 import sys
 from typing import Optional
 from functools import partial
 import warnings
+from typing import TYPE_CHECKING
 
 from ._abc import AsyncResource, SendStream, ReceiveStream
 from ._highlevel_generic import StapledStream
@@ -18,38 +21,46 @@ import trio
 
 # Linux-specific, but has complex lifetime management stuff so we hard-code it
 # here instead of hiding it behind the _subprocess_platform abstraction
-can_try_pidfd_open = True
-try:
-    from os import pidfd_open
-except ImportError:
-    if sys.platform == "linux":
-        import ctypes
+can_try_pidfd_open: bool
+if TYPE_CHECKING:
 
-        _cdll_for_pidfd_open = ctypes.CDLL(None, use_errno=True)
-        _cdll_for_pidfd_open.syscall.restype = ctypes.c_long
-        # pid and flags are actually int-sized, but the syscall() function
-        # always takes longs. (Except on x32 where long is 32-bits and syscall
-        # takes 64-bit arguments. But in the unlikely case that anyone is
-        # using x32, this will still work, b/c we only need to pass in 32 bits
-        # of data, and the C ABI doesn't distinguish between passing 32-bit vs
-        # 64-bit integers; our 32-bit values will get loaded into 64-bit
-        # registers where syscall() will find them.)
-        _cdll_for_pidfd_open.syscall.argtypes = [
-            ctypes.c_long,  # syscall number
-            ctypes.c_long,  # pid
-            ctypes.c_long,  # flags
-        ]
-        __NR_pidfd_open = 434
+    def pidfd_open(fd: int, flags: int) -> int:
+        ...
 
-        def pidfd_open(fd, flags):
-            result = _cdll_for_pidfd_open.syscall(__NR_pidfd_open, fd, flags)
-            if result < 0:
-                err = ctypes.get_errno()
-                raise OSError(err, os.strerror(err))
-            return result
 
-    else:
-        can_try_pidfd_open = False
+else:
+    can_try_pidfd_open = True
+    try:
+        from os import pidfd_open
+    except ImportError:
+        if sys.platform == "linux":
+            import ctypes
+
+            _cdll_for_pidfd_open = ctypes.CDLL(None, use_errno=True)
+            _cdll_for_pidfd_open.syscall.restype = ctypes.c_long
+            # pid and flags are actually int-sized, but the syscall() function
+            # always takes longs. (Except on x32 where long is 32-bits and syscall
+            # takes 64-bit arguments. But in the unlikely case that anyone is
+            # using x32, this will still work, b/c we only need to pass in 32 bits
+            # of data, and the C ABI doesn't distinguish between passing 32-bit vs
+            # 64-bit integers; our 32-bit values will get loaded into 64-bit
+            # registers where syscall() will find them.)
+            _cdll_for_pidfd_open.syscall.argtypes = [
+                ctypes.c_long,  # syscall number
+                ctypes.c_long,  # pid
+                ctypes.c_long,  # flags
+            ]
+            __NR_pidfd_open = 434
+
+            def pidfd_open(fd: int, flags: int) -> int:
+                result = _cdll_for_pidfd_open.syscall(__NR_pidfd_open, fd, flags)
+                if result < 0:
+                    err = ctypes.get_errno()
+                    raise OSError(err, os.strerror(err))
+                return result
+
+        else:
+            can_try_pidfd_open = False
 
 
 class Process(AsyncResource, metaclass=NoPublicConstructor):
@@ -442,10 +453,10 @@ async def run_process(
     :attr:`~subprocess.CompletedProcess.stderr` attributes of the
     returned :class:`~subprocess.CompletedProcess` object.  The value
     for any stream that was not captured will be ``None``.
-    
+
     If you want to capture both stdout and stderr while keeping them
     separate, pass ``capture_stdout=True, capture_stderr=True``.
-    
+
     If you want to capture both stdout and stderr but mixed together
     in the order they were printed, use: ``capture_stdout=True, stderr=subprocess.STDOUT``.
     This directs the child's stderr into its stdout, so the combined
