@@ -1,8 +1,10 @@
 import threading
 import queue as stdlib_queue
 import time
+import weakref
 
 import pytest
+from trio._core import TrioToken, current_trio_token
 
 from .. import _core
 from .. import Event, CapacityLimiter, sleep
@@ -576,3 +578,10 @@ def test_from_thread_run_during_shutdown():
 
     _core.run(main)
     assert record == ["ok"]
+
+
+async def test_trio_token_weak_referenceable():
+    token = current_trio_token()
+    assert isinstance(token, TrioToken)
+    weak_reference = weakref.ref(token)
+    assert token is weak_reference()
